sequencetools.divide_sequence_elements_by_greatest_common_divisor
=================================================================

.. autofunction:: abjad.tools.sequencetools.divide_sequence_elements_by_greatest_common_divisor.divide_sequence_elements_by_greatest_common_divisor
